***************************************
Saving the State of Your Jdaviz Session
***************************************

Reproducibility is a common goal.  While Jdaviz has no :guilabel:`Save` button, the various data products created within Jdaviz can be :ref:`exported to the notebook <export_data>` and, ultimately, saved locally using standard Python write commands.  This is the suggested workflow to ensure reproducibility in your analysis without having to retrace your steps in Jdaviz each time you run a notebook.  We also encourage users to manually record steps in their Jupyter notebook (or anywhere of convenience) with any details that may be of interest when running Jdaviz.
